*******
**PROGRAMA PARA CALCULAR BALANCE EN EL PROPENSITY SCORE
**EVALUACION PREP 2012
**DR. RAYMUNDO M. CAMPOS VAZQUEZ
*******

use "$data_new\PREP_Final.dta", clear

****************************
** Definiendo las caractersticas observables a incluir
****************************

global X_pob="pobtot pobmas pobfem pobent pobind pob012 pob1517 pob1824 pob60mas"
global X_educ="pob15ans graproes"
global X_caract="pobcasada pobcatol hogjefem"
global X_ocup="pea ocupada  pobsisal"
global X_assets="vivpitierra vivsinbien vivauto vivelec vivag vivdren"
global X_muni="poblacintotal ndicederezagosocial tipo_estrato"
****************************
*Variables Dependientes:
global Ya="per_seguridad per_seguridad2 seg2 seg22 per_conseg per_conseg2"
global Yb="asiste_esp per_condfi per_condfi2 participa"
global Yc="relacion relacion2 ind_cohsocial"

****************************
***Empezando Rutina
****************************

*********************************
****Pscore Routine
*PASO 1. Estimation of pscore
*********************************
*********************************

****
** 3 impactos: periodo 2010, 2011: 1 ao y 2 aos
****

**
*Modelo A: Estima todas las caractersticas observables
**
logit T1 $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni if T1!=.
predict pscore1_A if T1!=.

logit T2 $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni if T2!=.
predict pscore2_A if T2!=.

logit T3 $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni if T3!=.
predict pscore3_A if T3!=.

**
*Modelo B: Interacciones
**

local i=1
foreach var in ndicederezagosocial tipo_estrato {
	foreach var2 in $X_ocup $X_assets {
	quietly gen _X`i'=`var'*`var2'
	local i=`i'+1
	}
}

logit T1 $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni _X* if T1!=.
predict pscore1_B if T1!=.

logit T2 $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni _X* if T2!=.
predict pscore2_B if T2!=.

logit T3 $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni _X* if T3!=.
predict pscore3_B if T3!=.


*********************************
*PASO 3. BALANCEO Y SOPORTE COMN PARA CADA MTODO DE MATCHING
*********************************

***A
****Prueba de Estratificacin
***Reportar: display "% of Variables not Balanced Among Total" `totvar'/`total'
***Esto es el % variables no balanceadas

foreach var in A B {
foreach var2 in 1 2 3 {
display "pscore`var2'_`var'"
sort pscore`var2'_`var'
xtile block=pscore`var2'_`var' if pscore`var2'_`var'!=., nq(5)

table block T`var2', c(freq mean pscore`var2'_`var' sd pscore`var2'_`var' min pscore`var2'_`var' max pscore`var2'_`var') row col

******BALANCING X'S
local totvar=0
local total=0
forval s=1/5 {
quietly sum pscore`var2'_`var' if block==`s' & T`var2'==1 
local x=r(mean)
quietly sum pscore`var2'_`var' if block==`s' & T`var2'==0
local y=r(mean)
	if `x'!=. & `y'!=. {
		local numvar=0
		foreach var3 in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
			 _X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
		local total=`total'+1
			quietly ttest `var3' if block==`s', by(T`var2')		
				if r(p)<0.05 {
				display "Variable `var3' not balanced in block--" `s'
				local numvar=`numvar'+1
				}
		}
		display "Block--" `s'
		display "Number of Variables not Balanced--" `numvar'
		local totvar=`totvar'+`numvar'
	}
}
display "pscore`var2'_`var'"
display "% of Variables not Balanced Among Total" `totvar'/`total'
drop block
}
}

***B
****Pruebas de Sesgo Estandarizado, Verosimilitud y Diferencia de Medias

**MACTH: pscore
gen unif=runiform()

***Exploratory: Neighbor 1, Caliper 0.02
foreach var in A B {
foreach var2 in 1 2 3 {
display "pscore`var2'_`var'"
sort pscore`var2'_`var' unif
psmatch2 T`var2', outcome(per_seguridad) pscore(pscore`var2'_`var') neighbor(1) caliper(0.02)
bys T`var2': egen num=total(_weight!=. & _weight>0)
tab num
pstest $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni _X*, mweight(_weight) support(_support) sum
drop num
}
}

***Exploratory: Neighbor 3, Caliper 0.01
foreach var in A B {
foreach var2 in 1 2 3 {
display "pscore`var2'_`var'"
sort pscore`var2'_`var' unif
psmatch2 T`var2', outcome(per_seguridad) pscore(pscore`var2'_`var') neighbor(3) caliper(0.01)
bys T`var2': egen num=total(_weight!=. & _weight>0)
tab num
pstest $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni _X*, mweight(_weight) support(_support) sum
drop num
}
}


***Exploratory: Neighbor 3, Caliper 0.0075
foreach var in A B {
foreach var2 in 1 2 3 {
display "pscore`var2'_`var'"
sort pscore`var2'_`var' unif
psmatch2 T`var2', outcome(per_seguridad) pscore(pscore`var2'_`var') neighbor(3) caliper(0.0075)
bys T`var2': egen num=total(_weight!=. & _weight>0)
tab num
pstest $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni _X*, mweight(_weight) support(_support) sum
drop num
}
}

***Exploratory: Kernel Epanechnikov, Caliper 0.01
foreach var in A B {
foreach var2 in 1 2 3 {
display "pscore`var2'_`var'"
sort pscore`var2'_`var' unif
psmatch2 T`var2', outcome(per_seguridad) pscore(pscore`var2'_`var') kernel bwidth(0.01)
bys T`var2': egen num=total(_weight!=. & _weight>0)
tab num
pstest $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni _X*, mweight(_weight) support(_support) sum
drop num
}
}

***Exploratory: Kernel Epanechnikov, Caliper 0.0075
foreach var in A B {
foreach var2 in 1 2 3 {
display "pscore`var2'_`var'"
sort pscore`var2'_`var' unif
psmatch2 T`var2', outcome(per_seguridad) pscore(pscore`var2'_`var') kernel bwidth(0.0075)
bys T`var2': egen num=total(_weight!=. & _weight>0)
tab num
pstest $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni _X*, mweight(_weight) support(_support) sum
drop num
}
}



**********************************************
**********************************************
***START OF THE ROUTINE TO CALCULATE BALANCE
**********************************************

************************************************************
***BALANCE EN CADA MODELO
************************************************************
set more off

***********************************
****NEIGHBOR 1, CALIPER 0.02
***********************************
foreach var in A B {
foreach var2 in 1 2 3 {
display "pscore`var2'_`var'"
sort pscore`var2'_`var' unif
psmatch2 T`var2', outcome(per_seguridad) pscore(pscore`var2'_`var') neighbor(1) caliper(0.02)
tab _weight T`var2'
sum T`var2' if T`var2'==1 & _weight>0 & _weight!=.
local N_1a=r(N)
sum T`var2' if T`var2'==0 & _weight>0 & _weight!=.
local N_0a=r(N)

pstest $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni _X*, mweight(_weight) support(_support) sum
local mbb_a=r(medbiasbef)
local mba_a=r(medbiasaft)
local plrb_a=r(chiprobbef)
local plra_a=r(chiprobaft)
local xc=0
local xxc=0
foreach varx in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
	_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
quietly sum `varx' if T`var2'==0 
local rm0=r(mean)
local rse0=r(sd)/sqrt(r(N))
quietly sum `varx' if T`var2'==1
local rm1=r(mean)
local rse1=r(sd)/sqrt(r(N))
local diffse=sqrt((`rse0')^2+(`rse1')^2)
local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
local xc=`xc'+`x'
local xxc=`xxc'+1
}
local diffb_a=`xc'/`xxc'

local xc=0
local xxc=0
foreach varx in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
	_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
quietly sum `varx' if T`var2'==0 [aw=_weight]
local rm0=r(mean)
local rse0=r(sd)/sqrt(r(N))
quietly sum `varx' if T`var2'==1 [aw=_weight]
local rm1=r(mean)
local rse1=r(sd)/sqrt(r(N))
local diffse=sqrt((`rse0')^2+(`rse1')^2)
local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
local xc=`xc'+`x'
local xxc=`xxc'+1
}
local diffa_a=`xc'/`xxc'


xtile block=pscore`var2'_`var' if pscore`var2'_`var'!=., nq(5)
xtile blocka=pscore`var2'_`var' if pscore`var2'_`var'!=. [aw=_weight], nq(5)

******BALANCING X'S
local totvar=0
local total=0
forval s=1/5 {
quietly sum pscore`var2'_`var' if block==`s' & T`var2'==1 
local x=r(mean)
quietly sum pscore`var2'_`var' if block==`s' & T`var2'==0
local y=r(mean)
	if `x'!=. & `y'!=. {
		local numvar=0
		foreach var3 in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
		_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
		local total=`total'+1
			quietly ttest `var3' if block==`s', by(T`var2')		
				if r(p)<0.05 {
				display "Variable `var2' not balanced in block--" `s'
				local numvar=`numvar'+1
				}
		}
		display "Block--" `s'
		display "Number of Variables not Balanced--" `numvar'
		local totvar=`totvar'+`numvar'
	}
}
display "pscore`var2'_`var'"
display "% of Variables not Balanced Among Total" `totvar'/`total'
drop block
local stratb_a=`totvar'/`total'

local totvar=0
local total=0
forval s=1/5 {
quietly sum pscore`var2'_`var' if blocka==`s' & T`var2'==1 [aw=_weight]
local x=r(mean)
quietly sum pscore`var2'_`var' if blocka==`s' & T`var2'==0 [aw=_weight]
local y=r(mean)
	if `x'!=. & `y'!=. {
		local numvar=0
		foreach var3 in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
		_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
		local total=`total'+1
		quietly sum `var3' if T`var2'==0 [aw=_weight]
		local rm0=r(mean)
		local rse0=r(sd)/sqrt(r(N))
		quietly sum `var3' if T`var2'==1 [aw=_weight]
		local rm1=r(mean)
		local rse1=r(sd)/sqrt(r(N))
		local diffse=sqrt((`rse0')^2+(`rse1')^2)
		local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
				if `x'==1 {
				display "Variable `var3' not balanced in block--" `s'
				local numvar=`numvar'+1
				}
		}
		display "Block--" `s'
		display "Number of Variables not Balanced--" `numvar'
		local totvar=`totvar'+`numvar'
	}
}
display "% of Variables not Balanced Among Total" `totvar'/`total'
local strata_a=`totvar'/`total'

drop blocka
display "pscore`var2'_`var'"
display "NN1+R 0.02 " "Strata-Before  " "Strata-After  " "Median Before  " "Median After  " "LR Before  " "LR After " "%Diff Before  " "%Diff After  " "# Treat " "# Control "
display "NN1+R 0.02 " `stratb_a' "   " `strata_a' "   " `mbb_a' "   " `mba_a' "  "  `plrb_a' "   " `plra_a' "    " `diffb_a' "  " `diffa_a' "  " `N_1a'  "  " `N_0a'
}
}

***********************************
****NEIGHBOR 3, CALIPER 0.02
***********************************
foreach var in A B {
foreach var2 in 1 2 3 {
display "pscore`var2'_`var'"
sort pscore`var2'_`var' unif
psmatch2 T`var2', outcome(per_seguridad) pscore(pscore`var2'_`var') neighbor(3) caliper(0.02)
tab _weight T`var2'
sum T`var2' if T`var2'==1 & _weight>0 & _weight!=.
local N_1a=r(N)
sum T`var2' if T`var2'==0 & _weight>0 & _weight!=.
local N_0a=r(N)

pstest $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni _X*, mweight(_weight) support(_support) sum
local mbb_a=r(medbiasbef)
local mba_a=r(medbiasaft)
local plrb_a=r(chiprobbef)
local plra_a=r(chiprobaft)
local xc=0
local xxc=0
foreach varx in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
	_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
quietly sum `varx' if T`var2'==0 
local rm0=r(mean)
local rse0=r(sd)/sqrt(r(N))
quietly sum `varx' if T`var2'==1
local rm1=r(mean)
local rse1=r(sd)/sqrt(r(N))
local diffse=sqrt((`rse0')^2+(`rse1')^2)
local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
local xc=`xc'+`x'
local xxc=`xxc'+1
}
local diffb_a=`xc'/`xxc'

local xc=0
local xxc=0
foreach varx in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
	_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
quietly sum `varx' if T`var2'==0 [aw=_weight]
local rm0=r(mean)
local rse0=r(sd)/sqrt(r(N))
quietly sum `varx' if T`var2'==1 [aw=_weight]
local rm1=r(mean)
local rse1=r(sd)/sqrt(r(N))
local diffse=sqrt((`rse0')^2+(`rse1')^2)
local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
local xc=`xc'+`x'
local xxc=`xxc'+1
}
local diffa_a=`xc'/`xxc'


xtile block=pscore`var2'_`var' if pscore`var2'_`var'!=., nq(5)
xtile blocka=pscore`var2'_`var' if pscore`var2'_`var'!=. [aw=_weight], nq(5)

******BALANCING X'S
local totvar=0
local total=0
forval s=1/5 {
quietly sum pscore`var2'_`var' if block==`s' & T`var2'==1 
local x=r(mean)
quietly sum pscore`var2'_`var' if block==`s' & T`var2'==0
local y=r(mean)
	if `x'!=. & `y'!=. {
		local numvar=0
		foreach var3 in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
		_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
		local total=`total'+1
			quietly ttest `var3' if block==`s', by(T`var2')		
				if r(p)<0.05 {
				display "Variable `var2' not balanced in block--" `s'
				local numvar=`numvar'+1
				}
		}
		display "Block--" `s'
		display "Number of Variables not Balanced--" `numvar'
		local totvar=`totvar'+`numvar'
	}
}
display "pscore`var2'_`var'"
display "% of Variables not Balanced Among Total" `totvar'/`total'
drop block
local stratb_a=`totvar'/`total'

local totvar=0
local total=0
forval s=1/5 {
quietly sum pscore`var2'_`var' if blocka==`s' & T`var2'==1 [aw=_weight]
local x=r(mean)
quietly sum pscore`var2'_`var' if blocka==`s' & T`var2'==0 [aw=_weight]
local y=r(mean)
	if `x'!=. & `y'!=. {
		local numvar=0
		foreach var3 in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
		_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
		local total=`total'+1
		quietly sum `var3' if T`var2'==0 [aw=_weight]
		local rm0=r(mean)
		local rse0=r(sd)/sqrt(r(N))
		quietly sum `var3' if T`var2'==1 [aw=_weight]
		local rm1=r(mean)
		local rse1=r(sd)/sqrt(r(N))
		local diffse=sqrt((`rse0')^2+(`rse1')^2)
		local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
				if `x'==1 {
				display "Variable `var3' not balanced in block--" `s'
				local numvar=`numvar'+1
				}
		}
		display "Block--" `s'
		display "Number of Variables not Balanced--" `numvar'
		local totvar=`totvar'+`numvar'
	}
}
display "% of Variables not Balanced Among Total" `totvar'/`total'
local strata_a=`totvar'/`total'

drop blocka
display "pscore`var2'_`var'"
display "NN3+R 0.02 " "Strata-Before  " "Strata-After  " "Median Before  " "Median After  " "LR Before  " "LR After " "%Diff Before  " "%Diff After  " "# Treat " "# Control "
display "NN3+R 0.02 " `stratb_a' "   " `strata_a' "   " `mbb_a' "   " `mba_a' "  "  `plrb_a' "   " `plra_a' "    " `diffb_a' "  " `diffa_a' "  " `N_1a'  "  " `N_0a'
}
}

***********************************
*** 3 NEIGHBORS + CALIPER 0.01
***********************************
foreach var in A B {
foreach var2 in 1 2 3 {
display "pscore`var2'_`var'"
sort pscore`var2'_`var' unif
psmatch2 T`var2', outcome(per_seguridad) pscore(pscore`var2'_`var') neighbor(3) caliper(0.01)
tab _weight T`var2'
sum T`var2' if T`var2'==1 & _weight>0 & _weight!=.
local N_1a=r(N)
sum T`var2' if T`var2'==0 & _weight>0 & _weight!=.
local N_0a=r(N)

pstest $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni _X*, mweight(_weight) support(_support) sum
local mbb_a=r(medbiasbef)
local mba_a=r(medbiasaft)
local plrb_a=r(chiprobbef)
local plra_a=r(chiprobaft)
local xc=0
local xxc=0
foreach varx in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
	_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
quietly sum `varx' if T`var2'==0 
local rm0=r(mean)
local rse0=r(sd)/sqrt(r(N))
quietly sum `varx' if T`var2'==1
local rm1=r(mean)
local rse1=r(sd)/sqrt(r(N))
local diffse=sqrt((`rse0')^2+(`rse1')^2)
local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
local xc=`xc'+`x'
local xxc=`xxc'+1
}
local diffb_a=`xc'/`xxc'

local xc=0
local xxc=0
foreach varx in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
	_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
quietly sum `varx' if T`var2'==0 [aw=_weight]
local rm0=r(mean)
local rse0=r(sd)/sqrt(r(N))
quietly sum `varx' if T`var2'==1 [aw=_weight]
local rm1=r(mean)
local rse1=r(sd)/sqrt(r(N))
local diffse=sqrt((`rse0')^2+(`rse1')^2)
local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
local xc=`xc'+`x'
local xxc=`xxc'+1
}
local diffa_a=`xc'/`xxc'


xtile block=pscore`var2'_`var' if pscore`var2'_`var'!=., nq(5)
xtile blocka=pscore`var2'_`var' if pscore`var2'_`var'!=. [aw=_weight], nq(5)

******BALANCING X'S
local totvar=0
local total=0
forval s=1/5 {
quietly sum pscore`var2'_`var' if block==`s' & T`var2'==1 
local x=r(mean)
quietly sum pscore`var2'_`var' if block==`s' & T`var2'==0
local y=r(mean)
	if `x'!=. & `y'!=. {
		local numvar=0
		foreach var3 in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
		_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
		local total=`total'+1
			quietly ttest `var3' if block==`s', by(T`var2')		
				if r(p)<0.05 {
				display "Variable `var2' not balanced in block--" `s'
				local numvar=`numvar'+1
				}
		}
		display "Block--" `s'
		display "Number of Variables not Balanced--" `numvar'
		local totvar=`totvar'+`numvar'
	}
}
display "pscore`var2'_`var'"
display "% of Variables not Balanced Among Total" `totvar'/`total'
drop block
local stratb_a=`totvar'/`total'

local totvar=0
local total=0
forval s=1/5 {
quietly sum pscore`var2'_`var' if blocka==`s' & T`var2'==1 [aw=_weight]
local x=r(mean)
quietly sum pscore`var2'_`var' if blocka==`s' & T`var2'==0 [aw=_weight]
local y=r(mean)
	if `x'!=. & `y'!=. {
		local numvar=0
		foreach var3 in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
		_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
		local total=`total'+1
		quietly sum `var3' if T`var2'==0 [aw=_weight]
		local rm0=r(mean)
		local rse0=r(sd)/sqrt(r(N))
		quietly sum `var3' if T`var2'==1 [aw=_weight]
		local rm1=r(mean)
		local rse1=r(sd)/sqrt(r(N))
		local diffse=sqrt((`rse0')^2+(`rse1')^2)
		local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
				if `x'==1 {
				display "Variable `var3' not balanced in block--" `s'
				local numvar=`numvar'+1
				}
		}
		display "Block--" `s'
		display "Number of Variables not Balanced--" `numvar'
		local totvar=`totvar'+`numvar'
	}
}
display "% of Variables not Balanced Among Total" `totvar'/`total'
local strata_a=`totvar'/`total'

drop blocka
display "pscore`var2'_`var'"
display "NN3+R 0.01 " "Strata-Before" "Strata-After" "Median Before  " "Median After " "LR Before " "LR After " "%Diff Before " "%Diff After " "# Treat " "# Control "
display "NN3+R 0.01 " `stratb_a' " " `strata_a' " " `mbb_a' " " `mba_a' " "  `plrb_a' " " `plra_a' " " `diffb_a' " " `diffa_a' " " `N_1a' " " `N_0a'
}
}


**********************
****RADIUS CALIPER 0.02
**********************
foreach var in A B {
foreach var2 in 1 2 3 {
display "pscore`var2'_`var'"
sort pscore`var2'_`var' unif
psmatch2 T`var2', outcome(per_seguridad) pscore(pscore`var2'_`var') radius caliper(0.02)
tab _weight T`var2'
sum T`var2' if T`var2'==1 & _weight>0 & _weight!=.
local N_1a=r(N)
sum T`var2' if T`var2'==0 & _weight>0 & _weight!=.
local N_0a=r(N)

pstest $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni _X*, mweight(_weight) support(_support) sum
local mbb_a=r(medbiasbef)
local mba_a=r(medbiasaft)
local plrb_a=r(chiprobbef)
local plra_a=r(chiprobaft)
local xc=0
local xxc=0
foreach varx in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
	_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
quietly sum `varx' if T`var2'==0 
local rm0=r(mean)
local rse0=r(sd)/sqrt(r(N))
quietly sum `varx' if T`var2'==1
local rm1=r(mean)
local rse1=r(sd)/sqrt(r(N))
local diffse=sqrt((`rse0')^2+(`rse1')^2)
local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
local xc=`xc'+`x'
local xxc=`xxc'+1
}
local diffb_a=`xc'/`xxc'

local xc=0
local xxc=0
foreach varx in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
	_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
quietly sum `varx' if T`var2'==0 [aw=_weight]
local rm0=r(mean)
local rse0=r(sd)/sqrt(r(N))
quietly sum `varx' if T`var2'==1 [aw=_weight]
local rm1=r(mean)
local rse1=r(sd)/sqrt(r(N))
local diffse=sqrt((`rse0')^2+(`rse1')^2)
local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
local xc=`xc'+`x'
local xxc=`xxc'+1
}
local diffa_a=`xc'/`xxc'


xtile block=pscore`var2'_`var' if pscore`var2'_`var'!=., nq(5)
xtile blocka=pscore`var2'_`var' if pscore`var2'_`var'!=. [aw=_weight], nq(5)

******BALANCING X'S
local totvar=0
local total=0
forval s=1/5 {
quietly sum pscore`var2'_`var' if block==`s' & T`var2'==1 
local x=r(mean)
quietly sum pscore`var2'_`var' if block==`s' & T`var2'==0
local y=r(mean)
	if `x'!=. & `y'!=. {
		local numvar=0
		foreach var3 in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
		_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
		local total=`total'+1
			quietly ttest `var3' if block==`s', by(T`var2')		
				if r(p)<0.05 {
				display "Variable `var2' not balanced in block--" `s'
				local numvar=`numvar'+1
				}
		}
		display "Block--" `s'
		display "Number of Variables not Balanced--" `numvar'
		local totvar=`totvar'+`numvar'
	}
}
display "pscore`var2'_`var'"
display "% of Variables not Balanced Among Total" `totvar'/`total'
drop block
local stratb_a=`totvar'/`total'

local totvar=0
local total=0
forval s=1/5 {
quietly sum pscore`var2'_`var' if blocka==`s' & T`var2'==1 [aw=_weight]
local x=r(mean)
quietly sum pscore`var2'_`var' if blocka==`s' & T`var2'==0 [aw=_weight]
local y=r(mean)
	if `x'!=. & `y'!=. {
		local numvar=0
		foreach var3 in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
		_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
		local total=`total'+1
		quietly sum `var3' if T`var2'==0 [aw=_weight]
		local rm0=r(mean)
		local rse0=r(sd)/sqrt(r(N))
		quietly sum `var3' if T`var2'==1 [aw=_weight]
		local rm1=r(mean)
		local rse1=r(sd)/sqrt(r(N))
		local diffse=sqrt((`rse0')^2+(`rse1')^2)
		local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
				if `x'==1 {
				display "Variable `var3' not balanced in block--" `s'
				local numvar=`numvar'+1
				}
		}
		display "Block--" `s'
		display "Number of Variables not Balanced--" `numvar'
		local totvar=`totvar'+`numvar'
	}
}
display "% of Variables not Balanced Among Total" `totvar'/`total'
local strata_a=`totvar'/`total'

drop blocka
display "pscore`var2'_`var'"
display "R 0.01 " "Strata-Before" "Strata-After" "Median Before  " "Median After " "LR Before " "LR After " "%Diff Before " "%Diff After " "# Treat " "# Control "
display "R 0.01 " `stratb_a' " " `strata_a' " " `mbb_a' " " `mba_a' " "  `plrb_a' " " `plra_a' " " `diffb_a' " " `diffa_a' " " `N_1a' " " `N_0a'
}
}

**********************
****RADIUS CALIPER 0.01
**********************
foreach var in A B {
foreach var2 in 1 2 3 {
display "pscore`var2'_`var'"
sort pscore`var2'_`var' unif
psmatch2 T`var2', outcome(per_seguridad) pscore(pscore`var2'_`var') radius caliper(0.01)
tab _weight T`var2'
sum T`var2' if T`var2'==1 & _weight>0 & _weight!=.
local N_1a=r(N)
sum T`var2' if T`var2'==0 & _weight>0 & _weight!=.
local N_0a=r(N)

pstest $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni _X*, mweight(_weight) support(_support) sum
local mbb_a=r(medbiasbef)
local mba_a=r(medbiasaft)
local plrb_a=r(chiprobbef)
local plra_a=r(chiprobaft)
local xc=0
local xxc=0
foreach varx in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
	_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
quietly sum `varx' if T`var2'==0 
local rm0=r(mean)
local rse0=r(sd)/sqrt(r(N))
quietly sum `varx' if T`var2'==1
local rm1=r(mean)
local rse1=r(sd)/sqrt(r(N))
local diffse=sqrt((`rse0')^2+(`rse1')^2)
local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
local xc=`xc'+`x'
local xxc=`xxc'+1
}
local diffb_a=`xc'/`xxc'

local xc=0
local xxc=0
foreach varx in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
	_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
quietly sum `varx' if T`var2'==0 [aw=_weight]
local rm0=r(mean)
local rse0=r(sd)/sqrt(r(N))
quietly sum `varx' if T`var2'==1 [aw=_weight]
local rm1=r(mean)
local rse1=r(sd)/sqrt(r(N))
local diffse=sqrt((`rse0')^2+(`rse1')^2)
local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
local xc=`xc'+`x'
local xxc=`xxc'+1
}
local diffa_a=`xc'/`xxc'


xtile block=pscore`var2'_`var' if pscore`var2'_`var'!=., nq(5)
xtile blocka=pscore`var2'_`var' if pscore`var2'_`var'!=. [aw=_weight], nq(5)

******BALANCING X'S
local totvar=0
local total=0
forval s=1/5 {
quietly sum pscore`var2'_`var' if block==`s' & T`var2'==1 
local x=r(mean)
quietly sum pscore`var2'_`var' if block==`s' & T`var2'==0
local y=r(mean)
	if `x'!=. & `y'!=. {
		local numvar=0
		foreach var3 in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
		_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
		local total=`total'+1
			quietly ttest `var3' if block==`s', by(T`var2')		
				if r(p)<0.05 {
				display "Variable `var2' not balanced in block--" `s'
				local numvar=`numvar'+1
				}
		}
		display "Block--" `s'
		display "Number of Variables not Balanced--" `numvar'
		local totvar=`totvar'+`numvar'
	}
}
display "pscore`var2'_`var'"
display "% of Variables not Balanced Among Total" `totvar'/`total'
drop block
local stratb_a=`totvar'/`total'

local totvar=0
local total=0
forval s=1/5 {
quietly sum pscore`var2'_`var' if blocka==`s' & T`var2'==1 [aw=_weight]
local x=r(mean)
quietly sum pscore`var2'_`var' if blocka==`s' & T`var2'==0 [aw=_weight]
local y=r(mean)
	if `x'!=. & `y'!=. {
		local numvar=0
		foreach var3 in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
		_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
		local total=`total'+1
		quietly sum `var3' if T`var2'==0 [aw=_weight]
		local rm0=r(mean)
		local rse0=r(sd)/sqrt(r(N))
		quietly sum `var3' if T`var2'==1 [aw=_weight]
		local rm1=r(mean)
		local rse1=r(sd)/sqrt(r(N))
		local diffse=sqrt((`rse0')^2+(`rse1')^2)
		local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
				if `x'==1 {
				display "Variable `var3' not balanced in block--" `s'
				local numvar=`numvar'+1
				}
		}
		display "Block--" `s'
		display "Number of Variables not Balanced--" `numvar'
		local totvar=`totvar'+`numvar'
	}
}
display "% of Variables not Balanced Among Total" `totvar'/`total'
local strata_a=`totvar'/`total'

drop blocka
display "pscore`var2'_`var'"
display "R 0.0075 " "Strata-Before" "Strata-After" "Median Before  " "Median After " "LR Before " "LR After " "%Diff Before " "%Diff After " "# Treat " "# Control "
display "R 0.0075 " `stratb_a' " " `strata_a' " " `mbb_a' " " `mba_a' " "  `plrb_a' " " `plra_a' " " `diffb_a' " " `diffa_a' " " `N_1a' " " `N_0a'
}
}


**********************
****KERNEL: EPANECHNIKOV - BWIDTH 0.02
**********************
foreach var in A B {
foreach var2 in 1 2 3 {
display "pscore`var2'_`var'"
sort pscore`var2'_`var' unif
psmatch2 T`var2', outcome(per_seguridad) pscore(pscore`var2'_`var') kernel bwidth(0.02)
tab _weight T`var2'
sum T`var2' if T`var2'==1 & _weight>0 & _weight!=.
local N_1a=r(N)
sum T`var2' if T`var2'==0 & _weight>0 & _weight!=.
local N_0a=r(N)

pstest $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni _X*, mweight(_weight) support(_support) sum
local mbb_a=r(medbiasbef)
local mba_a=r(medbiasaft)
local plrb_a=r(chiprobbef)
local plra_a=r(chiprobaft)
local xc=0
local xxc=0
foreach varx in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
	_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
quietly sum `varx' if T`var2'==0 
local rm0=r(mean)
local rse0=r(sd)/sqrt(r(N))
quietly sum `varx' if T`var2'==1
local rm1=r(mean)
local rse1=r(sd)/sqrt(r(N))
local diffse=sqrt((`rse0')^2+(`rse1')^2)
local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
local xc=`xc'+`x'
local xxc=`xxc'+1
}
local diffb_a=`xc'/`xxc'

local xc=0
local xxc=0
foreach varx in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
	_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
quietly sum `varx' if T`var2'==0 [aw=_weight]
local rm0=r(mean)
local rse0=r(sd)/sqrt(r(N))
quietly sum `varx' if T`var2'==1 [aw=_weight]
local rm1=r(mean)
local rse1=r(sd)/sqrt(r(N))
local diffse=sqrt((`rse0')^2+(`rse1')^2)
local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
local xc=`xc'+`x'
local xxc=`xxc'+1
}
local diffa_a=`xc'/`xxc'


xtile block=pscore`var2'_`var' if pscore`var2'_`var'!=., nq(5)
xtile blocka=pscore`var2'_`var' if pscore`var2'_`var'!=. [aw=_weight], nq(5)

******BALANCING X'S
local totvar=0
local total=0
forval s=1/5 {
quietly sum pscore`var2'_`var' if block==`s' & T`var2'==1 
local x=r(mean)
quietly sum pscore`var2'_`var' if block==`s' & T`var2'==0
local y=r(mean)
	if `x'!=. & `y'!=. {
		local numvar=0
		foreach var3 in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
		_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
		local total=`total'+1
			quietly ttest `var3' if block==`s', by(T`var2')		
				if r(p)<0.05 {
				display "Variable `var2' not balanced in block--" `s'
				local numvar=`numvar'+1
				}
		}
		display "Block--" `s'
		display "Number of Variables not Balanced--" `numvar'
		local totvar=`totvar'+`numvar'
	}
}
display "pscore`var2'_`var'"
display "% of Variables not Balanced Among Total" `totvar'/`total'
drop block
local stratb_a=`totvar'/`total'

local totvar=0
local total=0
forval s=1/5 {
quietly sum pscore`var2'_`var' if blocka==`s' & T`var2'==1 [aw=_weight]
local x=r(mean)
quietly sum pscore`var2'_`var' if blocka==`s' & T`var2'==0 [aw=_weight]
local y=r(mean)
	if `x'!=. & `y'!=. {
		local numvar=0
		foreach var3 in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
		_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
		local total=`total'+1
		quietly sum `var3' if T`var2'==0 [aw=_weight]
		local rm0=r(mean)
		local rse0=r(sd)/sqrt(r(N))
		quietly sum `var3' if T`var2'==1 [aw=_weight]
		local rm1=r(mean)
		local rse1=r(sd)/sqrt(r(N))
		local diffse=sqrt((`rse0')^2+(`rse1')^2)
		local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
				if `x'==1 {
				display "Variable `var3' not balanced in block--" `s'
				local numvar=`numvar'+1
				}
		}
		display "Block--" `s'
		display "Number of Variables not Balanced--" `numvar'
		local totvar=`totvar'+`numvar'
	}
}
display "% of Variables not Balanced Among Total" `totvar'/`total'
local strata_a=`totvar'/`total'

drop blocka
display "pscore`var2'_`var'"
display "KERNEL BWIDTH 0.02 " "Strata-Before" "Strata-After" "Median Before  " "Median After " "LR Before " "LR After " "%Diff Before " "%Diff After " "# Treat " "# Control "
display "KERNEL BWIDTH 0.02 " `stratb_a' " " `strata_a' " " `mbb_a' " " `mba_a' " "  `plrb_a' " " `plra_a' " " `diffb_a' " " `diffa_a' " " `N_1a' " " `N_0a'
}
}

**********************
****KERNEL: EPANECHNIKOV - BWIDTH 0.01
**********************
foreach var in A B {
foreach var2 in 1 2 3 {
display "pscore`var2'_`var'"
sort pscore`var2'_`var' unif
psmatch2 T`var2', outcome(per_seguridad) pscore(pscore`var2'_`var') kernel bwidth(0.01)
tab _weight T`var2'
sum T`var2' if T`var2'==1 & _weight>0 & _weight!=.
local N_1a=r(N)
sum T`var2' if T`var2'==0 & _weight>0 & _weight!=.
local N_0a=r(N)

pstest $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni _X*, mweight(_weight) support(_support) sum
local mbb_a=r(medbiasbef)
local mba_a=r(medbiasaft)
local plrb_a=r(chiprobbef)
local plra_a=r(chiprobaft)
local xc=0
local xxc=0
foreach varx in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
	_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
quietly sum `varx' if T`var2'==0 
local rm0=r(mean)
local rse0=r(sd)/sqrt(r(N))
quietly sum `varx' if T`var2'==1
local rm1=r(mean)
local rse1=r(sd)/sqrt(r(N))
local diffse=sqrt((`rse0')^2+(`rse1')^2)
local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
local xc=`xc'+`x'
local xxc=`xxc'+1
}
local diffb_a=`xc'/`xxc'

local xc=0
local xxc=0
foreach varx in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
	_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
quietly sum `varx' if T`var2'==0 [aw=_weight]
local rm0=r(mean)
local rse0=r(sd)/sqrt(r(N))
quietly sum `varx' if T`var2'==1 [aw=_weight]
local rm1=r(mean)
local rse1=r(sd)/sqrt(r(N))
local diffse=sqrt((`rse0')^2+(`rse1')^2)
local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
local xc=`xc'+`x'
local xxc=`xxc'+1
}
local diffa_a=`xc'/`xxc'


xtile block=pscore`var2'_`var' if pscore`var2'_`var'!=., nq(5)
xtile blocka=pscore`var2'_`var' if pscore`var2'_`var'!=. [aw=_weight], nq(5)

******BALANCING X'S
local totvar=0
local total=0
forval s=1/5 {
quietly sum pscore`var2'_`var' if block==`s' & T`var2'==1 
local x=r(mean)
quietly sum pscore`var2'_`var' if block==`s' & T`var2'==0
local y=r(mean)
	if `x'!=. & `y'!=. {
		local numvar=0
		foreach var3 in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
		_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
		local total=`total'+1
			quietly ttest `var3' if block==`s', by(T`var2')		
				if r(p)<0.05 {
				display "Variable `var2' not balanced in block--" `s'
				local numvar=`numvar'+1
				}
		}
		display "Block--" `s'
		display "Number of Variables not Balanced--" `numvar'
		local totvar=`totvar'+`numvar'
	}
}
display "pscore`var2'_`var'"
display "% of Variables not Balanced Among Total" `totvar'/`total'
drop block
local stratb_a=`totvar'/`total'

local totvar=0
local total=0
forval s=1/5 {
quietly sum pscore`var2'_`var' if blocka==`s' & T`var2'==1 [aw=_weight]
local x=r(mean)
quietly sum pscore`var2'_`var' if blocka==`s' & T`var2'==0 [aw=_weight]
local y=r(mean)
	if `x'!=. & `y'!=. {
		local numvar=0
		foreach var3 in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
		_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
		local total=`total'+1
		quietly sum `var3' if T`var2'==0 [aw=_weight]
		local rm0=r(mean)
		local rse0=r(sd)/sqrt(r(N))
		quietly sum `var3' if T`var2'==1 [aw=_weight]
		local rm1=r(mean)
		local rse1=r(sd)/sqrt(r(N))
		local diffse=sqrt((`rse0')^2+(`rse1')^2)
		local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
				if `x'==1 {
				display "Variable `var3' not balanced in block--" `s'
				local numvar=`numvar'+1
				}
		}
		display "Block--" `s'
		display "Number of Variables not Balanced--" `numvar'
		local totvar=`totvar'+`numvar'
	}
}
display "% of Variables not Balanced Among Total" `totvar'/`total'
local strata_a=`totvar'/`total'

drop blocka
display "pscore`var2'_`var'"
display "KERNEL BWIDTH 0.01 " "Strata-Before" "Strata-After" "Median Before  " "Median After " "LR Before " "LR After " "%Diff Before " "%Diff After " "# Treat " "# Control "
display "KERNEL BWIDTH 0.01 " `stratb_a' " " `strata_a' " " `mbb_a' " " `mba_a' " "  `plrb_a' " " `plra_a' " " `diffb_a' " " `diffa_a' " " `N_1a' " " `N_0a'
}
}

**********************
****KERNEL: EPANECHNIKOV - BWIDTH 0.0075
**********************
foreach var in A B {
foreach var2 in 1 2 3 {
display "pscore`var2'_`var'"
sort pscore`var2'_`var' unif
psmatch2 T`var2', outcome(per_seguridad) pscore(pscore`var2'_`var') kernel bwidth(0.0075)
tab _weight T`var2'
sum T`var2' if T`var2'==1 & _weight>0 & _weight!=.
local N_1a=r(N)
sum T`var2' if T`var2'==0 & _weight>0 & _weight!=.
local N_0a=r(N)

pstest $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni _X*, mweight(_weight) support(_support) sum
local mbb_a=r(medbiasbef)
local mba_a=r(medbiasaft)
local plrb_a=r(chiprobbef)
local plra_a=r(chiprobaft)
local xc=0
local xxc=0
foreach varx in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
	_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
quietly sum `varx' if T`var2'==0 
local rm0=r(mean)
local rse0=r(sd)/sqrt(r(N))
quietly sum `varx' if T`var2'==1
local rm1=r(mean)
local rse1=r(sd)/sqrt(r(N))
local diffse=sqrt((`rse0')^2+(`rse1')^2)
local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
local xc=`xc'+`x'
local xxc=`xxc'+1
}
local diffb_a=`xc'/`xxc'

local xc=0
local xxc=0
foreach varx in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
	_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
quietly sum `varx' if T`var2'==0 [aw=_weight]
local rm0=r(mean)
local rse0=r(sd)/sqrt(r(N))
quietly sum `varx' if T`var2'==1 [aw=_weight]
local rm1=r(mean)
local rse1=r(sd)/sqrt(r(N))
local diffse=sqrt((`rse0')^2+(`rse1')^2)
local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
local xc=`xc'+`x'
local xxc=`xxc'+1
}
local diffa_a=`xc'/`xxc'


xtile block=pscore`var2'_`var' if pscore`var2'_`var'!=., nq(5)
xtile blocka=pscore`var2'_`var' if pscore`var2'_`var'!=. [aw=_weight], nq(5)

******BALANCING X'S
local totvar=0
local total=0
forval s=1/5 {
quietly sum pscore`var2'_`var' if block==`s' & T`var2'==1 
local x=r(mean)
quietly sum pscore`var2'_`var' if block==`s' & T`var2'==0
local y=r(mean)
	if `x'!=. & `y'!=. {
		local numvar=0
		foreach var3 in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
		_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
		local total=`total'+1
			quietly ttest `var3' if block==`s', by(T`var2')		
				if r(p)<0.05 {
				display "Variable `var2' not balanced in block--" `s'
				local numvar=`numvar'+1
				}
		}
		display "Block--" `s'
		display "Number of Variables not Balanced--" `numvar'
		local totvar=`totvar'+`numvar'
	}
}
display "pscore`var2'_`var'"
display "% of Variables not Balanced Among Total" `totvar'/`total'
drop block
local stratb_a=`totvar'/`total'

local totvar=0
local total=0
forval s=1/5 {
quietly sum pscore`var2'_`var' if blocka==`s' & T`var2'==1 [aw=_weight]
local x=r(mean)
quietly sum pscore`var2'_`var' if blocka==`s' & T`var2'==0 [aw=_weight]
local y=r(mean)
	if `x'!=. & `y'!=. {
		local numvar=0
		foreach var3 in $X_pob $X_educ $X_caract $X_ocup $X_assets $X_muni ////
		_X1 _X2 _X3 _X4 _X5 _X6 _X7 _X8 _X9 _X10 _X11 _X12 _X13 _X14 _X15 _X16 _X17 _X18 {
		local total=`total'+1
		quietly sum `var3' if T`var2'==0 [aw=_weight]
		local rm0=r(mean)
		local rse0=r(sd)/sqrt(r(N))
		quietly sum `var3' if T`var2'==1 [aw=_weight]
		local rm1=r(mean)
		local rse1=r(sd)/sqrt(r(N))
		local diffse=sqrt((`rse0')^2+(`rse1')^2)
		local x=cond(abs((`rm1'-`rm0')/`diffse')>1.96,1,0)
				if `x'==1 {
				display "Variable `var3' not balanced in block--" `s'
				local numvar=`numvar'+1
				}
		}
		display "Block--" `s'
		display "Number of Variables not Balanced--" `numvar'
		local totvar=`totvar'+`numvar'
	}
}
display "% of Variables not Balanced Among Total" `totvar'/`total'
local strata_a=`totvar'/`total'

drop blocka
display "pscore`var2'_`var'"
display "KERNEL BWIDTH 0.0075 " "Strata-Before" "Strata-After" "Median Before  " "Median After " "LR Before " "LR After " "%Diff Before " "%Diff After " "# Treat " "# Control "
display "KERNEL BWIDTH 0.0075 " `stratb_a' " " `strata_a' " " `mbb_a' " " `mba_a' " "  `plrb_a' " " `plra_a' " " `diffb_a' " " `diffa_a' " " `N_1a' " " `N_0a'
}
}

